Sophie

Sophie

distrib > Mageia > 5 > x86_64 > media > core-updates-src > by-pkgid > 9a3fa0a17cb4df796fd28ae58f5f7a80 > files > 4

glib2.0-2.42.1-2.1.mga5.src.rpm

diff -up ./gio/gdesktopappinfo.c.orig ./gio/gdesktopappinfo.c
--- ./gio/gdesktopappinfo.c.orig	2013-09-29 20:55:19.558860516 +0300
+++ ./gio/gdesktopappinfo.c	2013-09-29 21:19:41.934410279 +0300
@@ -1137,11 +1137,13 @@ prepend_terminal_to_vector (int    *argc
   term_argv = g_new0 (char *, 3);
 
   check = g_find_program_in_path ("gnome-terminal");
+  if (check == NULL)
+    check = g_find_program_in_path ("xfce4-terminal");
   if (check != NULL)
     {
       term_argv[0] = check;
       /* Note that gnome-terminal takes -x and
        * as -e in gnome-terminal is broken we use that. */
       term_argv[1] = g_strdup ("-x");
     }
   else
@@ -1137,11 +1137,13 @@ prepend_terminal_to_vector (int    *argc
     {
       term_argv[0] = check;
-      /* Note that gnome-terminal takes -x and
-       * as -e in gnome-terminal is broken we use that. */
+      /* Note that gnome-terminal and xfce4-terminal takes -x and
+       * as -e in gnome-terminal and xfce4-terminal is broken we use that. */
       term_argv[1] = g_strdup ("-x");
     }